==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_peace_town_disco.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",82,15)
end

function Chaba1()
    if(FLJ("RepairKeeperIsGunSmith")) then
        KEY()MS3("维修店老板其实是制枪者...")NOD()
        CAT("\n也行他能帮上你的忙。")NOD()
    elseif(FLJ("ChatWithChaba")) then
        Chaba1_chat()
    else
        KEY()
        MS3("哟，")NOD()
        CAT("\n居然是咪咪卡。")NOD()
        CAT("\n你不怕我们嘛？")NOD()CLR()
        FAC("jack_normal")CAT("\n为什么？")NOD()CLR()
        FAC()CAT("我们高第是以")
        CAT("\n咪咪卡为食的生物")NOD()
        CAT("\n但是在这个小镇上是不敢胡作非为的，")NOD()
        CAT("\n毕竟这里叫“和平小镇”。")NOD()CLR()
        FAC("jack_normal")CAT("话说回来这里好空啊，")NOD()
        CAT("\n是不是少了什么？")NOD()CLR()
        FAC()CAT("没错，")NOD()
        CAT("\n不久前我们的老大找到了一批货源，")NOD()
        CAT("\n为了交易无论如何都需要钱....")NOD()
        CAT("\n就把这里的各种设备都给卖掉了，")NOD()
        CAT("\n最后就给我留下了几盏灯。")NOD()CLR()
        FLP("ChatWithChaba")
        Chaba1_chat()
    end
end

function Chaba1_chat()
    KEY()
    MS3("\n话说你们找我有什么事嘛？")NOD()CLR()
    if(FLJ("ChatWithBalrog_GoodLuck")) then
        WayToCatchFirefly()
    else
        Nothing()
    end
end

function Nothing()
    KEY()
    FAC("jack_normal")MS3("\n没事...")NOD()
end

function WayToCatchFirefly()
    KEY()
    FAC("jack_normal")MS3("\n你知道萤火虫嘛？")NOD()CLR()
    FAC()CAT("这个当然知道，")NOD()
    CAT("\n在镇子西边的洞窟里有一些，")NOD()
    CAT("\n你是想要抓萤火虫嘛？")NOD()CLR()
    FAC("jack_normal")CAT("没错，")NOD()
    CAT("\n但我们没有办法捕获方法...")NOD()
    CAT("\n我们的武器恐怕只能杀死它们，")NOD()CLR()
    FAC()CAT("原来是泡泡枪和火球啊...")NOD()
    CAT("\n可以稍微借我看一下它们嘛？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n好吧。")NOD()CLR()
        AMC("hide_gun")
        GIT("Bubbler")
        FAC()CAT("将泡泡枪交了出去了。")NOD()
        GIT("Fireball")
        CAT("\n将火球交出去了。")NOD()CLR()
        GIT()
        SOU("CS_071_little_crash")
        CAT("\n喝！！")NOD()CLR()
        FAC("jack_normal")CAT("\n喂！你拿我们的枪干了什么？！")NOD()CLR()
        FAC()CAT("只是想看一下它们能不能合成...")NOD()
        CAT("\n结果一点反应也没有，真是无趣。")NOD()CLR()
        CAT("不过想想也是，")NOD()
        CAT("\n水属性和火属性的枪")
        CAT("\n当然也不太可能会反应。")NOD()CLR()
        FAC("jack_><")CAT("还好没有反应....")NOD()
        CAT("\n（要不然我们其中一个要打酱油了）")NOD()CLR()
        AMC("show_gun")
        GIT("Bubbler")
        FAC()CAT("将泡泡枪拿了回来。")NOD()
        GIT("Fireball")
        CAT("\n将火球拿了回来。")NOD()CLR()
        GIT()
    else
        FAC("jack_normal")CAT("不行！")NOD()
        CAT("\n这枪是我们最重要的东西。")NOD()
        CAT("\n不能随意交给它人。")NOD()CLR()
        FAC()CAT("\n这么说也是...")NOD()CLR()
    end
    FAC("jack_normal")CAT("话说你似乎对枪很了解啊？")NOD()
    CAT("\n而且你还知道它们的名字。")NOD()CLR()
    FAC()CAT("毕竟这两把也是那个制枪者的作品。")NOD()CLR()
    CAT("但他已经不再造枪了。")NOD()
    CAT("\n相对的开了一家维修店。")NOD()CLR()
    CAT("以他的本事的话，")NOD()
    CAT("\n一定能帮上你的。")NOD()CLR()
    FAC("jack_normal")CAT("\n谢谢你和我说这么多！")NOD()CLR()
    FAC()CAT("没事，我叫茶羽，")NOD()
    CAT("\n有空可以随时来这玩。")NOD()
    FLP("RepairKeeperIsGunSmith")
    MSA("AskGunsmithForHelp")
end

function ChabaGoHome()
    KEY()
    HMC()
    CMU("CS_Jenka")
    FAI(2)
    MS3("终于下班了...")NOD()
    CAT("\n不知道那两个拿枪的小鬼怎么样了。")NOD()
    CAT("\n一想起他们当时的眼神")
    CAT("\n总感觉接下来有什么大事会要发生...")NOD()CLR()
    CAT("不想了好累，")NOD()
    CAT("\n赶紧回家睡了。")NOD()CLO()
    FAO(0)
    TRA("CS_gaudi_city","ChabaGoHome",162,43)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_peace_town_disco.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",82,15)
end

function Chaba1()
    if(FLJ("RepairKeeperIsGunSmith")) then
        KEY()MS3("维修店老板其实是制枪者...")NOD()
        CAT("\n也许他能帮上你的忙。")NOD()
    elseif(FLJ("ChatWithChaba")) then
        Chaba1_chat()
    else
        KEY()
        MS3("哟，")NOD()
        CAT("\n居然是咪咪卡。")NOD()
        CAT("\n你不怕我们嘛？")NOD()CLR()
        FAC("jack_normal")CAT("\n为什么？")NOD()CLR()
        FAC()CAT("我们高第是以")
        CAT("\n咪咪卡为食的生物")NOD()
        CAT("\n但是在这个小镇上是不敢胡作非为的，")NOD()
        CAT("\n毕竟这里叫“和平小镇”。")NOD()CLR()
        FAC("jack_normal")CAT("话说回来这里好空啊，")NOD()
        CAT("\n是不是少了什么？")NOD()CLR()
        FAC()CAT("没错，")NOD()
        CAT("\n不久前我们的老大找到了一批货源，")NOD()
        CAT("\n为了交易无论如何都需要钱....")NOD()
        CAT("\n就把这里的各种设备都给卖掉了，")NOD()
        CAT("\n最后就给我留下了几盏灯。")NOD()CLR()
        FLP("ChatWithChaba")
        Chaba1_chat()
    end
end

function Chaba1_chat()
    KEY()
    MS3("\n话说你们找我有什么事嘛？")NOD()CLR()
    if(FLJ("ChatWithBalrog_GoodLuck")) then
        WayToCatchFirefly()
    else
        Nothing()
    end
end

function Nothing()
    KEY()
    FAC("jack_normal")MS3("\n没事...")NOD()
end

function WayToCatchFirefly()
    KEY()
    FAC("jack_normal")MS3("\n你知道萤火虫嘛？")NOD()CLR()
    FAC()CAT("这个当然知道，")NOD()
    CAT("\n在镇子西边的洞窟里有一些，")NOD()
    CAT("\n你是想要抓萤火虫嘛？")NOD()CLR()
    FAC("jack_normal")CAT("没错，")NOD()
    CAT("\n但我们没有办法捕获方法...")NOD()
    CAT("\n我们的武器恐怕只能杀死它们，")NOD()CLR()
    FAC()CAT("原来是泡泡枪和火球啊...")NOD()
    CAT("\n可以稍微借我看一下它们嘛？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n好吧。")NOD()CLR()
        AMC("hide_gun")
        GIT("Bubbler")
        FAC()CAT("将泡泡枪交出去了。")NOD()
        GIT("Fireball")
        CAT("\n将火球交出去了。")NOD()CLR()
        GIT()
        SOU("CS_071_little_crash")
        CAT("\n喝！！")NOD()CLR()
        FAC("jack_normal")CAT("\n喂！你拿我们的枪干了什么？！")NOD()CLR()
        FAC()CAT("只是想看一下它们能不能合成...")NOD()
        CAT("\n结果一点反应也没有，真是无趣。")NOD()CLR()
        CAT("不过想想也是，")NOD()
        CAT("\n水属性和火属性的枪")
        CAT("\n当然也不太可能会反应。")NOD()CLR()
        FAC("jack_><")CAT("还好没有反应....")NOD()
        CAT("\n（要不然我们其中一个要打酱油了）")NOD()CLR()
        AMC("show_gun")
        GIT("Bubbler")
        FAC()CAT("将泡泡枪拿了回来。")NOD()
        GIT("Fireball")
        CAT("\n将火球拿了回来。")NOD()CLR()
        GIT()
    else
        FAC("jack_normal")CAT("不行！")NOD()
        CAT("\n这枪是我们最重要的东西。")NOD()
        CAT("\n不能随意交给它人。")NOD()CLR()
        FAC()CAT("\n这么说也是...")NOD()CLR()
    end
    FAC("jack_normal")CAT("话说你似乎对枪很了解啊？")NOD()
    CAT("\n而且你还知道它们的名字。")NOD()CLR()
    FAC()CAT("毕竟这两把也是那个制枪者的作品。")NOD()CLR()
    CAT("但他已经不再造枪了。")NOD()
    CAT("\n相对的开了一家维修店。")NOD()CLR()
    CAT("以他的本事的话，")NOD()
    CAT("\n一定能帮上你的。")NOD()CLR()
    FAC("jack_normal")CAT("\n谢谢你和我说这么多！")NOD()CLR()
    FAC()CAT("没事，我叫茶羽，")NOD()
    CAT("\n有空可以随时来这玩。")NOD()
    FLP("RepairKeeperIsGunSmith")
    MSA("AskGunsmithForHelp")
end

function ChabaGoHome()
    KEY()
    HMC()
    CMU("CS_Jenka")
    FAI(2)
    MS3("终于下班了...")NOD()
    CAT("\n不知道那两个拿枪的小鬼怎么样了。")NOD()
    CAT("\n一想起他们当时的眼神")
    CAT("\n总感觉接下来有什么大事会要发生...")NOD()CLR()
    CAT("不想了好累，")NOD()
    CAT("\n赶紧回家睡了。")NOD()CLO()
    FAO(0)
    TRA("CS_gaudi_city","ChabaGoHome",162,43)
end
